<?php do_action('frontier_after_main'); ?>
</div>

<?php if ( is_active_sidebar('widgets_footer') ) : ?>
	<div id="footer" class="cf">
		<div id="widgets-wrap-footer" class="widget-column-<?php echo frontier_option('footer_widget_columns', '3'); ?> cf">
			<?php dynamic_sidebar('widgets_footer'); ?>
		</div>
	</div>
<?php endif; ?>

<div id="bottom-bar" class="cf">
	<?php do_action('frontier_before_bottom_bar'); ?>

	<?php if ( frontier_option('bottom_bar_text', get_bloginfo('name') . ' &copy; ' . date('Y')) ) : ?>
		<span id="bottom-bar-text"><?php echo frontier_option('bottom_bar_text', get_bloginfo('name') . ' &copy; ' . date('Y')); ?></span>
	<?php endif; ?>

	<?php if ( frontier_option('theme_link_disable', 0) == 0 ) : ?>
		<?php $frontier_theme_link = '<a href="' . esc_url( 'http://abirait.ru/' ) . '">"ABIRA-IT" для  спорта!</a>'; ?>
		<span id="theme-link"><?php echo apply_filters( 'frontier_theme_link', $frontier_theme_link ); ?></span>
	<?php endif; ?>

	<?php do_action('frontier_after_bottom_bar'); ?>
</div>

<?php do_action('frontier_after_container'); ?>
</div>

<?php do_action('frontier_after_body'); ?>

<?php wp_footer(); ?>

<!-- Yandex.Metrika informer --><a href="https://metrika.yandex.ru/stat/?id=30221931&amp;from=informer" target="_blank" rel="nofollow"><img src="//bs.yandex.ru/informer/30221931/3_1_FFFFFFFF_EFEFEFFF_0_pageviews" style="width:88px; height:31px; border:0;" alt="Яндекс.Метрика" title="Яндекс.Метрика: данные за сегодня (просмотры, визиты и уникальные посетители)" onclick="try{Ya.Metrika.informer({i:this,id:30221931,lang:'ru'});return false}catch(e){}"/></a><!-- /Yandex.Metrika informer --><!-- Yandex.Metrika counter --><script type="text/javascript">(function (d, w, c) { (w[c] = w[c] || []).push(function() { try { w.yaCounter30221931 = new Ya.Metrika({id:30221931, webvisor:true, clickmap:true, trackLinks:true, accurateTrackBounce:true}); } catch(e) { } }); var n = d.getElementsByTagName("script")[0], s = d.createElement("script"), f = function () { n.parentNode.insertBefore(s, n); }; s.type = "text/javascript"; s.async = true; s.src = (d.location.protocol == "https:" ? "https:" : "http:") + "//mc.yandex.ru/metrika/watch.js"; if (w.opera == "[object Opera]") { d.addEventListener("DOMContentLoaded", f, false); } else { f(); } })(document, window, "yandex_metrika_callbacks");</script><noscript><div><img src="//mc.yandex.ru/watch/30221931" style="position:absolute; left:-9999px;" alt="" /></div></noscript><!-- /Yandex.Metrika counter -->

</body>
</html>