/*
Noto Sans
Copyright 2015-2021 Google LLC. All Rights Reserved.
SIL Open Font License, Version 1.1 (https://opensource.org/licenses/OFL-1.1)

Noto Serif
Copyright 2012 Google Inc. All Rights Reserved.
SIL Open Font License, Version 1.1 (https://opensource.org/licenses/OFL-1.1)
*/

/* noto-sans-cyrillic-ext-400-normal */
@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-sans/noto-sans-cyrillic-ext-400-normal.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-400-normal.woff?ver=27') format('woff');
	unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
}

/* noto-sans-cyrillic-400-normal */
@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-sans/noto-sans-cyrillic-400-normal.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-400-normal.woff?ver=27') format('woff');
	unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
}

/* noto-sans-devanagari-400-normal */
@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-sans/noto-sans-devanagari-400-normal.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-400-normal.woff?ver=27') format('woff');
	unicode-range: U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200C-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;
}

/* noto-sans-greek-ext-400-normal */
@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-sans/noto-sans-greek-ext-400-normal.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-400-normal.woff?ver=27') format('woff');
	unicode-range: U+1F00-1FFF;
}

/* noto-sans-greek-400-normal */
@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-sans/noto-sans-greek-400-normal.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-400-normal.woff?ver=27') format('woff');
	unicode-range: U+0370-03FF;
}

/* noto-sans-vietnamese-400-normal */
@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-sans/noto-sans-vietnamese-400-normal.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-400-normal.woff?ver=27') format('woff');
	unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;
}

/* noto-sans-latin-ext-400-normal */
@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-sans/noto-sans-latin-ext-400-normal.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-400-normal.woff?ver=27') format('woff');
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}

/* noto-sans-latin-400-normal */
@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-sans/noto-sans-latin-400-normal.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-400-normal.woff?ver=27') format('woff');
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}

/* noto-sans-cyrillic-ext-400-italic */
@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-sans/noto-sans-cyrillic-ext-400-italic.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-400-italic.woff?ver=27') format('woff');
	unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
}

/* noto-sans-cyrillic-400-italic */
@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-sans/noto-sans-cyrillic-400-italic.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-400-italic.woff?ver=27') format('woff');
	unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
}

/* noto-sans-devanagari-400-italic */
@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-sans/noto-sans-devanagari-400-italic.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-400-italic.woff?ver=27') format('woff');
	unicode-range: U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200C-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;
}

/* noto-sans-greek-ext-400-italic */
@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-sans/noto-sans-greek-ext-400-italic.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-400-italic.woff?ver=27') format('woff');
	unicode-range: U+1F00-1FFF;
}

/* noto-sans-greek-400-italic */
@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-sans/noto-sans-greek-400-italic.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-400-italic.woff?ver=27') format('woff');
	unicode-range: U+0370-03FF;
}

/* noto-sans-vietnamese-400-italic */
@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-sans/noto-sans-vietnamese-400-italic.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-400-italic.woff?ver=27') format('woff');
	unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;
}

/* noto-sans-latin-ext-400-italic */
@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-sans/noto-sans-latin-ext-400-italic.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-400-italic.woff?ver=27') format('woff');
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}

/* noto-sans-latin-400-italic */
@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-sans/noto-sans-latin-400-italic.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-400-italic.woff?ver=27') format('woff');
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}

/* noto-sans-cyrillic-ext-700-normal */
@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-sans/noto-sans-cyrillic-ext-700-normal.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-700-normal.woff?ver=27') format('woff');
	unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
}

/* noto-sans-cyrillic-700-normal */
@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-sans/noto-sans-cyrillic-700-normal.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-700-normal.woff?ver=27') format('woff');
	unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
}

/* noto-sans-devanagari-700-normal */
@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-sans/noto-sans-devanagari-700-normal.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-700-normal.woff?ver=27') format('woff');
	unicode-range: U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200C-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;
}

/* noto-sans-greek-ext-700-normal */
@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-sans/noto-sans-greek-ext-700-normal.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-700-normal.woff?ver=27') format('woff');
	unicode-range: U+1F00-1FFF;
}

/* noto-sans-greek-700-normal */
@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-sans/noto-sans-greek-700-normal.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-700-normal.woff?ver=27') format('woff');
	unicode-range: U+0370-03FF;
}

/* noto-sans-vietnamese-700-normal */
@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-sans/noto-sans-vietnamese-700-normal.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-700-normal.woff?ver=27') format('woff');
	unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;
}

/* noto-sans-latin-ext-700-normal */
@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-sans/noto-sans-latin-ext-700-normal.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-700-normal.woff?ver=27') format('woff');
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}

/* noto-sans-latin-700-normal */
@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-sans/noto-sans-latin-700-normal.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-700-normal.woff?ver=27') format('woff');
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}

/* noto-sans-cyrillic-ext-700-italic */
@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-sans/noto-sans-cyrillic-ext-700-italic.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-700-italic.woff?ver=27') format('woff');
	unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
}

/* noto-sans-cyrillic-700-italic */
@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-sans/noto-sans-cyrillic-700-italic.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-700-italic.woff?ver=27') format('woff');
	unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
}

/* noto-sans-devanagari-700-italic */
@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-sans/noto-sans-devanagari-700-italic.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-700-italic.woff?ver=27') format('woff');
	unicode-range: U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200C-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;
}

/* noto-sans-greek-ext-700-italic */
@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-sans/noto-sans-greek-ext-700-italic.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-700-italic.woff?ver=27') format('woff');
	unicode-range: U+1F00-1FFF;
}

/* noto-sans-greek-700-italic */
@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-sans/noto-sans-greek-700-italic.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-700-italic.woff?ver=27') format('woff');
	unicode-range: U+0370-03FF;
}

/* noto-sans-vietnamese-700-italic */
@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-sans/noto-sans-vietnamese-700-italic.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-700-italic.woff?ver=27') format('woff');
	unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;
}

/* noto-sans-latin-ext-700-italic */
@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-sans/noto-sans-latin-ext-700-italic.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-700-italic.woff?ver=27') format('woff');
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}

/* noto-sans-latin-700-italic */
@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-sans/noto-sans-latin-700-italic.woff2?ver=27') format('woff2'),
		url('./noto-sans/noto-sans-all-700-italic.woff?ver=27') format('woff');
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}

/* noto-serif-cyrillic-ext-400-italic */
@font-face {
	font-family: 'Noto Serif';
	font-style: italic;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-serif/noto-serif-cyrillic-ext-400-italic.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-400-italic.woff?ver=21') format('woff');
	unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
}

/* noto-serif-cyrillic-400-italic */
@font-face {
	font-family: 'Noto Serif';
	font-style: italic;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-serif/noto-serif-cyrillic-400-italic.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-400-italic.woff?ver=21') format('woff');
	unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
}

/* noto-serif-greek-ext-400-italic */
@font-face {
	font-family: 'Noto Serif';
	font-style: italic;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-serif/noto-serif-greek-ext-400-italic.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-400-italic.woff?ver=21') format('woff');
	unicode-range: U+1F00-1FFF;
}

/* noto-serif-greek-400-italic */
@font-face {
	font-family: 'Noto Serif';
	font-style: italic;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-serif/noto-serif-greek-400-italic.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-400-italic.woff?ver=21') format('woff');
	unicode-range: U+0370-03FF;
}

/* noto-serif-vietnamese-400-italic */
@font-face {
	font-family: 'Noto Serif';
	font-style: italic;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-serif/noto-serif-vietnamese-400-italic.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-400-italic.woff?ver=21') format('woff');
	unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;
}

/* noto-serif-latin-ext-400-italic */
@font-face {
	font-family: 'Noto Serif';
	font-style: italic;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-serif/noto-serif-latin-ext-400-italic.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-400-italic.woff?ver=21') format('woff');
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}

/* noto-serif-latin-400-italic */
@font-face {
	font-family: 'Noto Serif';
	font-style: italic;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-serif/noto-serif-latin-400-italic.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-400-italic.woff?ver=21') format('woff');
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}

/* noto-serif-cyrillic-ext-700-italic */
@font-face {
	font-family: 'Noto Serif';
	font-style: italic;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-serif/noto-serif-cyrillic-ext-700-italic.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-700-italic.woff?ver=21') format('woff');
	unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
}

/* noto-serif-cyrillic-700-italic */
@font-face {
	font-family: 'Noto Serif';
	font-style: italic;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-serif/noto-serif-cyrillic-700-italic.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-700-italic.woff?ver=21') format('woff');
	unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
}

/* noto-serif-greek-ext-700-italic */
@font-face {
	font-family: 'Noto Serif';
	font-style: italic;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-serif/noto-serif-greek-ext-700-italic.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-700-italic.woff?ver=21') format('woff');
	unicode-range: U+1F00-1FFF;
}

/* noto-serif-greek-700-italic */
@font-face {
	font-family: 'Noto Serif';
	font-style: italic;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-serif/noto-serif-greek-700-italic.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-700-italic.woff?ver=21') format('woff');
	unicode-range: U+0370-03FF;
}

/* noto-serif-vietnamese-700-italic */
@font-face {
	font-family: 'Noto Serif';
	font-style: italic;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-serif/noto-serif-vietnamese-700-italic.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-700-italic.woff?ver=21') format('woff');
	unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;
}

/* noto-serif-latin-ext-700-italic */
@font-face {
	font-family: 'Noto Serif';
	font-style: italic;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-serif/noto-serif-latin-ext-700-italic.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-700-italic.woff?ver=21') format('woff');
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}

/* noto-serif-latin-700-italic */
@font-face {
	font-family: 'Noto Serif';
	font-style: italic;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-serif/noto-serif-latin-700-italic.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-700-italic.woff?ver=21') format('woff');
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}

/* noto-serif-cyrillic-ext-400-normal */
@font-face {
	font-family: 'Noto Serif';
	font-style: normal;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-serif/noto-serif-cyrillic-ext-400-normal.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-400-normal.woff?ver=21') format('woff');
	unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
}

/* noto-serif-cyrillic-400-normal */
@font-face {
	font-family: 'Noto Serif';
	font-style: normal;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-serif/noto-serif-cyrillic-400-normal.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-400-normal.woff?ver=21') format('woff');
	unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
}

/* noto-serif-greek-ext-400-normal */
@font-face {
	font-family: 'Noto Serif';
	font-style: normal;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-serif/noto-serif-greek-ext-400-normal.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-400-normal.woff?ver=21') format('woff');
	unicode-range: U+1F00-1FFF;
}

/* noto-serif-greek-400-normal */
@font-face {
	font-family: 'Noto Serif';
	font-style: normal;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-serif/noto-serif-greek-400-normal.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-400-normal.woff?ver=21') format('woff');
	unicode-range: U+0370-03FF;
}

/* noto-serif-vietnamese-400-normal */
@font-face {
	font-family: 'Noto Serif';
	font-style: normal;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-serif/noto-serif-vietnamese-400-normal.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-400-normal.woff?ver=21') format('woff');
	unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;
}

/* noto-serif-latin-ext-400-normal */
@font-face {
	font-family: 'Noto Serif';
	font-style: normal;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-serif/noto-serif-latin-ext-400-normal.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-400-normal.woff?ver=21') format('woff');
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}

/* noto-serif-latin-400-normal */
@font-face {
	font-family: 'Noto Serif';
	font-style: normal;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./noto-serif/noto-serif-latin-400-normal.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-400-normal.woff?ver=21') format('woff');
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}

/* noto-serif-cyrillic-ext-700-normal */
@font-face {
	font-family: 'Noto Serif';
	font-style: normal;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-serif/noto-serif-cyrillic-ext-700-normal.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-700-normal.woff?ver=21') format('woff');
	unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
}

/* noto-serif-cyrillic-700-normal */
@font-face {
	font-family: 'Noto Serif';
	font-style: normal;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-serif/noto-serif-cyrillic-700-normal.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-700-normal.woff?ver=21') format('woff');
	unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
}

/* noto-serif-greek-ext-700-normal */
@font-face {
	font-family: 'Noto Serif';
	font-style: normal;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-serif/noto-serif-greek-ext-700-normal.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-700-normal.woff?ver=21') format('woff');
	unicode-range: U+1F00-1FFF;
}

/* noto-serif-greek-700-normal */
@font-face {
	font-family: 'Noto Serif';
	font-style: normal;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-serif/noto-serif-greek-700-normal.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-700-normal.woff?ver=21') format('woff');
	unicode-range: U+0370-03FF;
}

/* noto-serif-vietnamese-700-normal */
@font-face {
	font-family: 'Noto Serif';
	font-style: normal;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-serif/noto-serif-vietnamese-700-normal.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-700-normal.woff?ver=21') format('woff');
	unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;
}

/* noto-serif-latin-ext-700-normal */
@font-face {
	font-family: 'Noto Serif';
	font-style: normal;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-serif/noto-serif-latin-ext-700-normal.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-700-normal.woff?ver=21') format('woff');
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}

/* noto-serif-latin-700-normal */
@font-face {
	font-family: 'Noto Serif';
	font-style: normal;
	font-display: fallback;
	font-weight: 700;
	src:
		url('./noto-serif/noto-serif-latin-700-normal.woff2?ver=21') format('woff2'),
		url('./noto-serif/noto-serif-all-700-normal.woff?ver=21') format('woff');
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}
