/*
Libre Franklin
Copyright 2020 The LibreFranklin Project Authors (https://github.com/impallari/Libre-Franklin)
SIL Open Font License, Version 1.1 (https://opensource.org/licenses/OFL-1.1)
*/

/* libre-franklin-vietnamese-300-normal */
@font-face {
	font-family: 'Libre Franklin';
	font-style: normal;
	font-display: fallback;
	font-weight: 300;
	src:
		url('./libre-franklin/libre-franklin-vietnamese-300-normal.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-300-normal.woff?ver=13') format('woff');
	unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;
}

/* libre-franklin-latin-ext-300-normal */
@font-face {
	font-family: 'Libre Franklin';
	font-style: normal;
	font-display: fallback;
	font-weight: 300;
	src:
		url('./libre-franklin/libre-franklin-latin-ext-300-normal.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-300-normal.woff?ver=13') format('woff');
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}

/* libre-franklin-latin-300-normal */
@font-face {
	font-family: 'Libre Franklin';
	font-style: normal;
	font-display: fallback;
	font-weight: 300;
	src:
		url('./libre-franklin/libre-franklin-latin-300-normal.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-300-normal.woff?ver=13') format('woff');
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}

/* libre-franklin-vietnamese-300-italic */
@font-face {
	font-family: 'Libre Franklin';
	font-style: italic;
	font-display: fallback;
	font-weight: 300;
	src:
		url('./libre-franklin/libre-franklin-vietnamese-300-italic.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-300-italic.woff?ver=13') format('woff');
	unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;
}

/* libre-franklin-latin-ext-300-italic */
@font-face {
	font-family: 'Libre Franklin';
	font-style: italic;
	font-display: fallback;
	font-weight: 300;
	src:
		url('./libre-franklin/libre-franklin-latin-ext-300-italic.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-300-italic.woff?ver=13') format('woff');
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}

/* libre-franklin-latin-300-italic */
@font-face {
	font-family: 'Libre Franklin';
	font-style: italic;
	font-display: fallback;
	font-weight: 300;
	src:
		url('./libre-franklin/libre-franklin-latin-300-italic.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-300-italic.woff?ver=13') format('woff');
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}

/* libre-franklin-vietnamese-400-normal */
@font-face {
	font-family: 'Libre Franklin';
	font-style: normal;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./libre-franklin/libre-franklin-vietnamese-400-normal.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-400-normal.woff?ver=13') format('woff');
	unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;
}

/* libre-franklin-latin-ext-400-normal */
@font-face {
	font-family: 'Libre Franklin';
	font-style: normal;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./libre-franklin/libre-franklin-latin-ext-400-normal.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-400-normal.woff?ver=13') format('woff');
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}

/* libre-franklin-latin-400-normal */
@font-face {
	font-family: 'Libre Franklin';
	font-style: normal;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./libre-franklin/libre-franklin-latin-400-normal.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-400-normal.woff?ver=13') format('woff');
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}

/* libre-franklin-vietnamese-400-italic */
@font-face {
	font-family: 'Libre Franklin';
	font-style: italic;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./libre-franklin/libre-franklin-vietnamese-400-italic.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-400-italic.woff?ver=13') format('woff');
	unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;
}

/* libre-franklin-latin-ext-400-italic */
@font-face {
	font-family: 'Libre Franklin';
	font-style: italic;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./libre-franklin/libre-franklin-latin-ext-400-italic.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-400-italic.woff?ver=13') format('woff');
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}

/* libre-franklin-latin-400-italic */
@font-face {
	font-family: 'Libre Franklin';
	font-style: italic;
	font-display: fallback;
	font-weight: 400;
	src:
		url('./libre-franklin/libre-franklin-latin-400-italic.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-400-italic.woff?ver=13') format('woff');
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}

/* libre-franklin-vietnamese-600-normal */
@font-face {
	font-family: 'Libre Franklin';
	font-style: normal;
	font-display: fallback;
	font-weight: 600;
	src:
		url('./libre-franklin/libre-franklin-vietnamese-600-normal.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-600-normal.woff?ver=13') format('woff');
	unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;
}

/* libre-franklin-latin-ext-600-normal */
@font-face {
	font-family: 'Libre Franklin';
	font-style: normal;
	font-display: fallback;
	font-weight: 600;
	src:
		url('./libre-franklin/libre-franklin-latin-ext-600-normal.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-600-normal.woff?ver=13') format('woff');
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}

/* libre-franklin-latin-600-normal */
@font-face {
	font-family: 'Libre Franklin';
	font-style: normal;
	font-display: fallback;
	font-weight: 600;
	src:
		url('./libre-franklin/libre-franklin-latin-600-normal.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-600-normal.woff?ver=13') format('woff');
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}

/* libre-franklin-vietnamese-600-italic */
@font-face {
	font-family: 'Libre Franklin';
	font-style: italic;
	font-display: fallback;
	font-weight: 600;
	src:
		url('./libre-franklin/libre-franklin-vietnamese-600-italic.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-600-italic.woff?ver=13') format('woff');
	unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;
}

/* libre-franklin-latin-ext-600-italic */
@font-face {
	font-family: 'Libre Franklin';
	font-style: italic;
	font-display: fallback;
	font-weight: 600;
	src:
		url('./libre-franklin/libre-franklin-latin-ext-600-italic.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-600-italic.woff?ver=13') format('woff');
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}

/* libre-franklin-latin-600-italic */
@font-face {
	font-family: 'Libre Franklin';
	font-style: italic;
	font-display: fallback;
	font-weight: 600;
	src:
		url('./libre-franklin/libre-franklin-latin-600-italic.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-600-italic.woff?ver=13') format('woff');
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}

/* libre-franklin-vietnamese-800-normal */
@font-face {
	font-family: 'Libre Franklin';
	font-style: normal;
	font-display: fallback;
	font-weight: 800;
	src:
		url('./libre-franklin/libre-franklin-vietnamese-800-normal.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-800-normal.woff?ver=13') format('woff');
	unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;
}

/* libre-franklin-latin-ext-800-normal */
@font-face {
	font-family: 'Libre Franklin';
	font-style: normal;
	font-display: fallback;
	font-weight: 800;
	src:
		url('./libre-franklin/libre-franklin-latin-ext-800-normal.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-800-normal.woff?ver=13') format('woff');
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}

/* libre-franklin-latin-800-normal */
@font-face {
	font-family: 'Libre Franklin';
	font-style: normal;
	font-display: fallback;
	font-weight: 800;
	src:
		url('./libre-franklin/libre-franklin-latin-800-normal.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-800-normal.woff?ver=13') format('woff');
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}

/* libre-franklin-vietnamese-800-italic */
@font-face {
	font-family: 'Libre Franklin';
	font-style: italic;
	font-display: fallback;
	font-weight: 800;
	src:
		url('./libre-franklin/libre-franklin-vietnamese-800-italic.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-800-italic.woff?ver=13') format('woff');
	unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;
}

/* libre-franklin-latin-ext-800-italic */
@font-face {
	font-family: 'Libre Franklin';
	font-style: italic;
	font-display: fallback;
	font-weight: 800;
	src:
		url('./libre-franklin/libre-franklin-latin-ext-800-italic.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-800-italic.woff?ver=13') format('woff');
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}

/* libre-franklin-latin-800-italic */
@font-face {
	font-family: 'Libre Franklin';
	font-style: italic;
	font-display: fallback;
	font-weight: 800;
	src:
		url('./libre-franklin/libre-franklin-latin-800-italic.woff2?ver=13') format('woff2'),
		url('./libre-franklin/libre-franklin-all-800-italic.woff?ver=13') format('woff');
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}
